@@ -12,8 +12,7 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-import mock
-
+from unittest import mock
 
 from heatclient import exc as heatexceptions
 from oslo_concurrency import processutils
