@@ -107,7 +107,6 @@ _EXISTING_PASSWORDS = {
     'RabbitPassword': 'ahuHRXdPMx9rzCdjD9CJJNCgA',
     'RpcPassword': 'ahuHRXdPMx9rzCdjD9CJJNCgA',
     'NotifyPassword': 'ahuHRXdPMx9rzCdjD9CJJNCgA',
-    'CephAdminKey': b'AQCQXtlXAAAAABAAT4Gk+U8EqqStL+JFa9bp1Q==',
     'HAProxyStatsPassword': 'P8tbdK6n4YUkTaUyy8XgEVTe6',
     'CeilometerPassword': 'RRdpwK6qf2pbKz2UtzxqauAdk',
     'GnocchiPassword': 'cRYHcUkMuJeK3vyU9pCaznUZc',
@@ -121,9 +120,7 @@ _EXISTING_PASSWORDS = {
     'OctaviaCaKeyPassphrase': 'SLj4c3uCk4DDxPwQOG1Heb==',
     'ManilaPassword': 'NYJN86Fua3X8AVFWmMhQa2zTH',
     'NeutronMetadataProxySharedSecret': 'Q2YgUCwmBkYdqsdhhCF4hbghu',
-    'CephMdsKey': b'AQCQXtlXAAAAABAAT4Gk+U8EqqStL+JFa9bp1Q==',
     'CephManilaClientKey': b'AQANOFFY1NW6AxAAu6jWI3YSOsp2QWusb5Y3DQ==',
-    'CephMonKey': b'AQCQXtlXAAAAABAA9l+59N3yH+C49Y0JiKeGFg==',
     'CephGrafanaAdminPassword': 'NYJN86Fua3X8AVFWmMhQa2zTH',
     'CephDashboardAdminPassword': 'NYJN86Fua3X8AVFWmMhQa2zTH',
     'SwiftHashSuffix': 'td8mV6k7TYEGKCDvjVBwckpn9',
@@ -744,7 +741,7 @@ class PlanTest(base.TestCase):
         }
         mock_resource = mock.MagicMock()
         mock_resource.attributes = {
-            'endpoint_map': {},
+            'endpoint_map': None,
             'value': None
         }
         mock_orchestration.resources.get.return_value = mock_resource
@@ -910,6 +907,7 @@ class PlanTest(base.TestCase):
 
         existing_passwords = _EXISTING_PASSWORDS.copy()
         existing_passwords.pop("AdminPassword")
+        existing_passwords.pop("PcsdPassword")
 
         swift = mock.MagicMock(url="http://test.com")
         mock_env = yaml.safe_dump({
@@ -926,6 +924,7 @@ class PlanTest(base.TestCase):
         mock_orchestration.stacks.environment.return_value = {
             'parameter_defaults': {
                 'AdminPassword': 'ExistingPasswordInHeat',
+                'PcsdPassword': 'MyPassword'
             }
         }
 
@@ -941,6 +940,7 @@ class PlanTest(base.TestCase):
         result = plan_utils.generate_passwords(swift, mock_orchestration)
 
         existing_passwords["AdminPassword"] = "ExistingPasswordInHeat"
+        existing_passwords["PcsdPassword"] = "MyPassword"
         # ensure old passwords used and no new generation
         self.assertEqual(existing_passwords, result)
         mock_cache.assert_called_once_with(
@@ -1034,7 +1034,7 @@ class PlanTest(base.TestCase):
 
         kib.assert_called_once_with(
             [os.path.join(sys.prefix, 'share', 'tripleo-common',
-                          'container-images', 'overcloud_containers.yaml.j2')]
+                          'container-images', 'tripleo_containers.yaml.j2')]
         )
         params = {
             'ContainerNovaComputeImage': 't/cb-nova-compute:liberty',
